import uuid
from designatev2 import common
from designatev2 import lists


class CheckId(object):
    def check_id(self, val):
        try:
            return str(uuid.UUID(val)).replace('-', '') == val
        except (TypeError, ValueError, AttributeError):
            return False


resource_lists = {
    'zone': lists.zone_list,
}


response_keys = {
    'zone': 'zones',
}


def get_by_name_or_uuid_multiple(resource_arg_name_pairs):
    def wrap(func):
        def wrapped_f(*args, **kwargs):
            results = []
            args_start = 0
            for index, (resource, arg_name) in enumerate(
                    resource_arg_name_pairs):
                if arg_name in kwargs:
                    ref = kwargs.pop(arg_name, None)
                else:
                    ref = args[index]
                    args_start += 1
                cloud_name = kwargs['cloud_name']
                checker = CheckId()
                if checker.check_id(ref):
                    results.append(ref)
                else:
                    # Then we have name not uuid
                    resp_key = response_keys[resource]
                    resp = resource_lists[resource](
                        name=ref, cloud_name=cloud_name)[resp_key]
                    if len(resp) == 0:
                        raise common.ResourceNotFound(resp_key, ref)
                    elif len(resp) > 1:
                        raise common.MultipleResourcesFound(resp_key, ref)
                    results.append(resp[0]['id'])
                results.extend(args[args_start:])
            return func(*results, **kwargs)
        return wrapped_f
    return wrap
